
if {![info exists vTcl(sourcing)]} {

    # Provoke name search
    catch {package require bogus-package-name}
    set packageNames [package names]

    package require BWidget
    switch $tcl_platform(platform) {
	windows {
	}
	default {
	    option add *ScrolledWindow.size 14
	}
    }
    
    package require Tk
    switch $tcl_platform(platform) {
	windows {
            option add *Button.padY 0
	}
	default {
            option add *Scrollbar.width 10
            option add *Scrollbar.highlightThickness 0
            option add *Scrollbar.elementBorderWidth 2
            option add *Scrollbar.borderWidth 2
	}
    }
    
}

#############################################################################
# Visual Tcl v1.60 Project
#




#############################################################################
## vTcl Code to Load Stock Images


if {![info exist vTcl(sourcing)]} {
#############################################################################
## Procedure:  vTcl:rename

proc ::vTcl:rename {name} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    regsub -all "\\." $name "_" ret
    regsub -all "\\-" $ret "_" ret
    regsub -all " " $ret "_" ret
    regsub -all "/" $ret "__" ret
    regsub -all "::" $ret "__" ret

    return [string tolower $ret]
}

#############################################################################
## Procedure:  vTcl:image:create_new_image

proc ::vTcl:image:create_new_image {filename {description {no description}} {type {}} {data {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    # Does the image already exist?
    if {[info exists ::vTcl(images,files)]} {
        if {[lsearch -exact $::vTcl(images,files) $filename] > -1} { return }
    }

    if {![info exists ::vTcl(sourcing)] && [string length $data] > 0} {
        set object [image create  [vTcl:image:get_creation_type $filename]  -data $data]
    } else {
        # Wait a minute... Does the file actually exist?
        if {! [file exists $filename] } {
            # Try current directory
            set script [file dirname [info script]]
            set filename [file join $script [file tail $filename] ]
        }

        if {![file exists $filename]} {
            set description "file not found!"
            ## will add 'broken image' again when img is fixed, for now create empty
            set object [image create photo -width 1 -height 1]
        } else {
            set object [image create  [vTcl:image:get_creation_type $filename]  -file $filename]
        }
    }

    set reference [vTcl:rename $filename]
    set ::vTcl(images,$reference,image)       $object
    set ::vTcl(images,$reference,description) $description
    set ::vTcl(images,$reference,type)        $type
    set ::vTcl(images,filename,$object)       $filename

    lappend ::vTcl(images,files) $filename
    lappend ::vTcl(images,$type) $object

    # return image name in case caller might want it
    return $object
}

#############################################################################
## Procedure:  vTcl:image:get_image

proc ::vTcl:image:get_image {filename} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    set reference [vTcl:rename $filename]

    # Let's do some checking first
    if {![info exists ::vTcl(images,$reference,image)]} {
        # Well, the path may be wrong; in that case check
        # only the filename instead, without the path.

        set imageTail [file tail $filename]

        foreach oneFile $::vTcl(images,files) {
            if {[file tail $oneFile] == $imageTail} {
                set reference [vTcl:rename $oneFile]
                break
            }
        }
    }
    return $::vTcl(images,$reference,image)
}

#############################################################################
## Procedure:  vTcl:image:get_creation_type

proc ::vTcl:image:get_creation_type {filename} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    switch [string tolower [file extension $filename]] {
        .ppm -
        .jpg -
        .bmp -
        .gif    {return photo}
        .xbm    {return bitmap}
        default {return photo}
    }
}

foreach img {


            } {
    eval set _file [lindex $img 0]
    vTcl:image:create_new_image\
        $_file [lindex $img 1] [lindex $img 2] [lindex $img 3]
}

}
#############################################################################
## vTcl Code to Load User Images

catch {package require Img}

foreach img {

        {{[file join / home ag cvs q q-synth images open.gif]} {user image} user {
R0lGODlhFgAWAOcAAAIatiZm2k6a/pKe1qLG+srK4gI6xtre+mp2wkaO/t7e
7rLa/gpK0urq+nq2/qamyk565uLy/mKa6jZOygIiujp+9g5S0nqy8p6m2u7y
+nqCyqbe/maK3sbG5qK66i5q2u7+/hpa0m6e7tbi+rLm/gI6ygIqvqquzq7C
8pau5jJu2rLK9mqS5tLW6sru/rrq/iZi8i5aznqi6oqS0kZy0gIqyvb2/h5e
1m6q/o62+hI6tlaK4vL+/hpGviJOxkZavjJy8t7i9ra22hI60kaW/l6W6gIW
yrq61h5a7pbS/r7u/mKG3gIiygIevn6y/oq2+ub2/kJq4tr2/mJ2yvr6/gI6
3m6i7kp+4ipWyiJi7gIuwpbC9h5q8s7S7r6+3v7+/naK0s7y/qLK/kaG5j5a
0u7u+gIy1pq68sLu/laS+qrO+prO/hpS5lqe/nZ+ylKO6oa69gYytjp23oKq
9gY+3i5i0uL+/rrm/h4+xiZKwn6Kyl6a+j523qKq3kJ+9r7W+uLi9ipm6iJW
0naa5iZi1nai7oq+/hJC3kJi1maO7tby/jZm1sby/ubm9oau9m6m/kqG9lKK
+jpy3q7S9p7S/rKy0jp29maS6mae7kZy5tba9srO7sLC3nKW5tra7gIuvn6m
7s72/jZq1gImvgIaxnqy+r7C6mae+gIetgImtjZy3m6W5h5i1o669h5KwgIm
zgJC5oay9vLy+oK6/k6e/sLK7hY+uiZSyjJ29pa++hpCviJa0nae6maW5gIe
ygYy0t7e9rq63oKK0rLS+rKy2n6m9r7q/qLS/ubm+ipm2pae2hJS0rbm/m6S
4tbW7n6i7nKq/h5GwtLS6sbu/jJi0ub+/r7m/rLS8s7O6iJi1pK6+gZC5u7u
/vLy/srK5t7e8mp2xhpa1m6e8jJu3gIqzgIewr6+4uLi+nai8sLC4gImwnqy
/gImuv//////////////////////////////////////////////////////
/////////////////////yH5BAEKAP8ALAAAAAAWABYAAAj+AP8JHEiwoMGD
CBMqFOhGw0KEMzQFQfCQoAZzNhpwU2aQlRURmCQUYfBPDwZk3bg1QMYNXEE+
oaYpeUFiiwZvX6ikXHmu1g+CckIxMkYiRR8eX77Y2ImsETdhBFUJVTMAWNKk
S1Vq4sBhSTQtnz5JZeShy9WcOrkdEHQplqM56MSNGhfzGA1QoGTwGtSpUzNB
ItYRISKASw0TH8IwerMKxZ9haghsaRXrySwBCYhU+KXu3wehFqAciGAnzJ01
s3C0SYAr0BBfRkb9CxBq1hUQUq5No7TuFKQKWdgcesXECCkK/wiFGnPGDpok
huBA2+MHCBI6Zsy8MtIEebYXIUCDGNuQpNS6R2n8ZIEFC3vxJgJvXNihyIW1
BWJy5CjGAUKmKIiQMQEeqMQnBwpX6VQGMsB4Io03HXghRCVTFPjPMuGcpVQZ
DQDiiTPYdGBKMMTkMVAJLGhIhSyNKOBMAZwcUckJD6QykAGEqCCKKItQU0cM
WNzigys96KKDLXEAUNFDAQEAOw==}}
        {{[file join / home ag cvs q q-synth images play.gif]} {user image} user {
R0lGODlhGAAYAKUAAG5ubldXV2dnZwAAADIyMsTExF1dXTExMcXFxeTk5C0t
Lbe3t+/v79zc3CgoKK+vr+Dg4CQkJMfHx5qamo6Ojh8fH6WlpZiYmIiIiBsb
G62trYWFhYODg4aGhpKSksHBwRYWFpCQkHR0dDo6OhISEg0NDXp6eoqKigkJ
CQQEBHBwcD8/P///////////////////////////////////////////////
/////////////////////////////////yH5BAEKAD8ALAAAAAAYABgAAAZ4
wJ9wSCwaj8ikcskcAgLNZEAwiB4JBUPVSjwgElruULFgNMJixwOyOG+tkYdk
QnFzKxbJBVNHNzMTGhscHR4ffksgIRMcHBQaIiNvSyQbF46QklYlJiePkZNM
KCaBoGIpIhOmYgMqq6wAmmJCAyuhXAO3s7u8vT9BADs=}}
        {{[file join / home ag cvs q q-synth images stop.gif]} {user image} user {
R0lGODlhFgAWAOcAAAAAAAEBAQICAgMDAwQEBAUFBQYGBgcHBwgICAkJCQoK
CgsLCwwMDA0NDQ4ODg8PDxAQEBERERISEhMTExQUFBUVFRYWFhcXFxgYGBkZ
GRoaGhsbGxwcHB0dHR4eHh8fHyAgICEhISIiIiMjIyQkJCUlJSYmJicnJygo
KCkpKSoqKisrKywsLC0tLS4uLi8vLzAwMDExMTIyMjMzMzQ0NDU1NTY2Njc3
Nzg4ODk5OTo6Ojs7Ozw8PD09PT4+Pj8/P0BAQEFBQUJCQkNDQ0REREVFRUZG
RkdHR0hISElJSUpKSktLS0xMTE1NTU5OTk9PT1BQUFFRUVJSUlNTU1RUVFVV
VVZWVldXV1hYWFlZWVpaWltbW1xcXF1dXV5eXl9fX2BgYGFhYWJiYmNjY2Rk
ZGVlZWZmZmdnZ2hoaGlpaWpqamtra2xsbG1tbW5ubm9vb3BwcHFxcXJycnNz
c3R0dHV1dXZ2dnd3d3h4eHl5eXp6ent7e3x8fH19fX5+fn9/f4CAgIGBgYKC
goODg4SEhIWFhYaGhoeHh4iIiImJiYqKiouLi4yMjI2NjY6Ojo+Pj5CQkJGR
kZKSkpOTk5SUlJWVlZaWlpeXl5iYmJmZmZqampubm5ycnJ2dnZ6enp+fn6Cg
oKGhoaKioqOjo6SkpKWlpaampqenp6ioqKmpqaqqqqurq6ysrK2tra6urq+v
r7CwsLGxsbKysrOzs7S0tLW1tba2tre3t7i4uLm5ubq6uru7u7y8vL29vb6+
vr+/v8DAwMHBwcLCwsPDw8TExMXFxcbGxsfHx8jIyMnJycrKysvLy8zMzM3N
zc7Ozs/Pz9DQ0NHR0dLS0tPT09TU1NXV1dbW1tfX19jY2NnZ2dra2tvb29zc
3N3d3d7e3t/f3+Dg4OHh4eLi4uPj4+Tk5OXl5ebm5ufn5+jo6Onp6erq6uvr
6+zs7O3t7e7u7u/v7/Dw8PHx8fLy8vPz8/T09PX19fb29vf39/j4+Pn5+fr6
+vv7+/z8/P39/f7+/v///yH5BAEKAP4ALAAAAAAWABYAAAjIAP0JHEiwoMGD
CBMqXMiwob8ACypciOCgogMIIgIAAICQQKRFiBpBGknpzZowJDgeTODI2bt/
MGGa4yYnikqDDRSNWxauZ09uvPjYROiAz79cuWYpnQWrUc2bBYv+e3WoKqJE
mJwOPejADr1gVhMpaiTozVaDXb8euqpoEVmzUAmmDcbW7duzUb0uE+vWESZK
TxE2WBOOFqZSiEuBwhR4ZZRXciJLjhylSdyBBHJE2cyZc5IilwUGIJCAgcWK
G1M7XM26tWuGAQEAOw==}}
        {{[file join / home ag cvs q q-synth images record.gif]} {user image} user {
R0lGODlhFgAWAMYAAMYAAMQAAMIAAMAAAL0AALsAAMkAAMwAANofH+pNTex8
fOldXdQuLr4AALQAAMoAAOIqKvysrP/Hx/GwsPCwsPfMzP27u9pGRq0AAO9M
TP/Q0PzExO+goPXPz/rKyu2AgK8AAKgAAMsAAO9DQ/+4uPytrfKzs+xxcaoA
AOIdHf+fn/KQkNQwMKEAAPtcXP+GhvxlZakAANkGBv9tbfgzM/QPD/IAAJoA
AOkVFf9TU9wAAJgAAMEAAOwcHP85Of8eHtsAAJUAAL8AAOwPD5MAAOkBAf8G
Bv0FBfYAAN0AAJEAALoAANYAAP0AAP4BAfwAAPsAAPxAQI8AAP8EBJwAALMA
AN0KCv8TE/8iIs0KCowAALMCAu8dHf8lJeodHZMCAqwAAK8DA+8qKv81Neoq
KpMDA4oAAKcAAKoEBNcmJv9GRs0mJpMEBKAAAKoKCsckJOVAQORAQMAkJJwK
CosAAJcAAJIAAJAAAI4AAP///////////////////////////yH5BAEKAH8A
LAAAAAAWABYAAAf+gH+Cg4SFhoeCAAECAwQFiIYGBwgJCgoLDA0OkH8PBxAR
EhITFBUSFhcOGIeeGRobHB2ioh4aHyAhhiIjJCUms8ASJCcohQYpKioryczN
ySwthAcuL9XW19cwMYMAMjPf4OHgNDU2AjeCATg57O3u7TbxOjuCPD0++Pk+
P/z98TZAgggSMqSfwYM//gEhIohAESMQIR6JaASJxYtJlAhawqSJEydPoFCM
AqWkSSFSBgmZwrJlxJYwqRCqYuWKTZsRsdy0mUVLoS1cugjtQnFoFy9fDIEJ
I2aMU4pOx5ApY+bQGTRp1KiJqFXNGjZVIbVx8wYOnDhx5Myhw4nQjToJQezc
wdO27qFAADs=}}
        {{[file join / home ag cvs q q-synth images make.gif]} {user image} user {
R0lGODlhFgAWAOcAADmV5USd6Eug6keb50OV5T+P4jqJ4DaD3TJ92y132Clx
1iRr0yBl0RtfzhdZzBJTyQ5NxwpHxAdCwgU/vwI4sgAypIvP/4TJ/33B/3W6
/22y/2Wq/12h/1SZ/0uQ/0KH/zl//zB2/ydt/x5k/xVb/wxS/wRK/wNJ/wNA
8QAyq02j7ITI/37C/3e7/3C0/2it/2Cl/1id/1CV/0iN/z+E/zZ7/y1z/yRq
/xxh/xNY/wpP/wND9gEysVuo67/h/7ze/7nb/7XX/7HU/67Q/6rM/6bI/6LE
/53A/5m8/5W4/5Cz/4yv/4eq/4Kl/n+i/n6h/X2g/Xqa9R1Is2qv6/////7+
//39/vv7/Pn5+/f3+vb2+fDv9DhetWmu6vT0+O7t8zhdtGms6fv7/fLy9+zr
8jdctGiq6PHx9unp8DZbs2ep5/j4+/Pz9+/v9efn7jVasman5vn5/O3t9OXl
7TRZsmWm5ezs8+Pj7DNYsWSl5Pb2+urq8uHh6jNYsGOj4+jo8d/f6TJXsGKi
4vr6/BPRDgmMAO7u9Ofn8N7d6GKg4bT/r1L/ROXl79zc52Gf4SD/COPj7tvb
5mCd3+Li7drZ5l6a3vr6+/n5+vf2+fX09/Ly9vHw9e/u8xWZANTT4DV/1FeR
11SM1FGI0U6Dzkt+ykh6x0V1xEJxwQw7p///////////////////////////
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
/////////////////////yH5BAEKAP8ALAAAAAAWABYAAAj+AAEEEDCAQAED
BxAkULCAQQMHDyBEkDCBQoUAFi5gyKBhA4cOHj6ACCFiBIkSJk6cQJFCxQoW
LVy8gBFDxgwaNWzcwJFDh8oTO3j08PEDSBAhQ4gUMXIESRIlS5g0cfIEShQp
U6ho3cp1axUrV7Bk0bKFS5euaKl8DTvWyxcwYdJy/SpGrBYvY8iUMSNXK127
eM+gSaOm7981d9mcaePmDZy+VsTEQexFcRs5c+jUkRt5cuLFcuzcwZMnbec1
eiqDtrOHTx8/aE+nthx6zx9AgQR1jTyIkG9ChdoYYv3nEKJAibjyXkOIiqJF
hYbbPsSoUSBHW5frIfT8USHi1CFPRQokSevy390LqQ8/iVKgSpYuYcqkaROn
Toq6eweEqFEkSp4E8gkooYgyCimlmHJKJ4ss4l0gEEYYCCr/VGjhhZ14d+GG
HG5YSIcghghiQAA7}}
        {{[file join / home ag cvs q q-synth images edit.gif]} {user image} user {
R0lGODlhFgAWAOcAAM3R3c/T3snO2sTI1cHF07K3yN+JId+ZYMNkNP////3+
/vX3+vHz+O3v9tesivrOAP7WUf7nyeq4kaYuBfj5+/P1+fDx+OiuOP7bAP6i
AP6hCv6NL7c7CPv8/ff4+/HUu/jGAP6/AP6eAP6IBeRaCfCyTv7fAP6nAv6e
Af50DtJtQPfp3PjCAf7LA/6nBf6QCPJmDJFtcIyRo/KxX/7iB/6yC/6rCv6A
FcVSIMnN2sjM2XR4hfz27ve3CP7VEP6xEf6fFfh6GsCTiszQ3MrP2/fGgP7n
Gv7CGv61GP6TJM9aG9XZ49TX49PW4ve1Hv7cJf67Iv6wJP6TL8GEdNnc5tba
5PnSoP3iL/7PL/6/Kv6lNtxyKt7a3+Dj7N/i69zf6fnBOf7nQf7FN/6/Nv6l
RcN4Xebo8OHk7XN3hPXRrP3eRf7YSf7JQf64S954K97R1Ofp8eXn8ODj69PW
32pte/b4+vjLcf7vYv7RUf7LTv64XtKMaevt9OTn7tbY4M/Q2mlsevXKif7i
d/7UWv7LYeSOQs2xsNfZ4NPV3dDS28/R2s3P2PHDjv7hpvjJibpkQdTW3tHT
3OK0ifjWtbZdOtLP06F8aqOMgsGBZ9nb4dPV3tvd5qBzYqlxX9vd4tnb4+Di
6tWvqefp7eXn7OTl697g6Ojq8ert8+Pm7vn6/PDy+O7w99LW4P//////////
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
/////////////////////yH5BAEKAP8ALAAAAAAWABYAAAj+AAEEGEhQwAAC
BQwcQPCvocOGARJIlKhgAYMGDh5AiCBhwkOIEylSqGDhAoYMGjZw+PgvYsgE
HTx8ABFCxAgSLFu+hEmhhIkTKFKoKMDSZcgOK1i0cPECRgwZMj4anahgBo0a
Nm7gyKFjh9SdPHr4+AEkiJAhRLw+nCqxiJEjSJIoWcKkiVqHbBU4eQIlipQp
VKhUuQsypJUrWLJo2cKli5cvhHVSBRNGzBgyZcycOeMFzVcFoNOoWcOmjZs3
cOLImUPna53Xdu7gyaNnD58+fv78AfTVg+9AggYRKmToEKJEihbxXpvAtwdG
ERo5euTHD6RIiXb39i0pwiRKlapMX8/emrlzS5cwZcokPpKmTZ7N++bUydP6
6p9ApY4ccYH/UKKMMgoppZhyChxmoMIfTB10kEoqdSxQAQOqrMLHgZGxssOG
HHboYWQBAQA7}}

            } {
    eval set _file [lindex $img 0]
    vTcl:image:create_new_image\
        $_file [lindex $img 1] [lindex $img 2] [lindex $img 3]
}

#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
#############################################################################
## Library Procedure:  Window

proc ::Window {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global vTcl
    foreach {cmd name newname} [lrange $args 0 2] {}
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[winfo exists $newname] && [wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
#############################################################################
## Library Procedure:  vTcl:DefineAlias

proc ::vTcl:DefineAlias {target alias widgetProc top_or_alias cmdalias} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global widget
    set widget($alias) $target
    set widget(rev,$target) $alias
    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }
    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target
        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:DoCmdOption

proc ::vTcl:DoCmdOption {target cmd} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}
#############################################################################
## Library Procedure:  vTcl:FireEvent

proc ::vTcl:FireEvent {target event {params {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## The window may have disappeared
    if {![winfo exists $target]} return
    ## Process each binding tag, looking for the event
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                foreach rep "\{%W $target\} $params" {
                    regsub -all [lindex $rep 0] $bind_code [lindex $rep 1] bind_code
                }
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    ## break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}
#############################################################################
## Library Procedure:  vTcl:Toplevel:WidgetProc

proc ::vTcl:Toplevel:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    set command [lindex $args 0]
    set args [lrange $args 1 end]
    switch -- [string tolower $command] {
        "setvar" {
            foreach {varname value} $args {}
            if {$value == ""} {
                return [set ::${w}::${varname}]
            } else {
                return [set ::${w}::${varname} $value]
            }
        }
        "hide" - "show" {
            Window [string tolower $command] $w
        }
        "showmodal" {
            ## modal dialog ends when window is destroyed
            Window show $w; raise $w
            grab $w; tkwait window $w; grab release $w
        }
        "startmodal" {
            ## ends when endmodal called
            Window show $w; raise $w
            set ::${w}::_modal 1
            grab $w; tkwait variable ::${w}::_modal; grab release $w
        }
        "endmodal" {
            ## ends modal dialog started with startmodal, argument is var name
            set ::${w}::_modal 0
            Window hide $w
        }
        default {
            uplevel $w $command $args
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:WidgetProc

proc ::vTcl:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }

    set command [lindex $args 0]
    set args [lrange $args 1 end]
    uplevel $w $command $args
}
#############################################################################
## Library Procedure:  vTcl:toplevel

proc ::vTcl:toplevel {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {set _modal 0}
}
}


if {[info exists vTcl(sourcing)]} {

proc vTcl:project:info {} {
    set base .top90
    namespace eval ::widgets::$base {
        set set,origin 0
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets::$base.fra91 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    set site_3_0 $base.fra91
    namespace eval ::widgets::$site_3_0.but91 {
        array set save {-_tooltip 1 -command 1 -image 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.ent90 {
        array set save {-background 1 -insertbackground 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.cpd90 {
        array set save {-_tooltip 1 -command 1 -image 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.but92 {
        array set save {-_tooltip 1 -command 1 -image 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.com92 {
        array set save {-command 1 -entrybg 1 -highlightcolor 1 -insertbackground 1 -modifycmd 1 -postcommand 1 -selectbackground 1 -selectforeground 1 -takefocus 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.lab93 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_3_0.spi95 {
        array set save {-command 1 -entrybg 1 -entryfg 1 -highlightcolor 1 -insertbackground 1 -modifycmd 1 -range 1 -selectbackground 1 -selectforeground 1 -takefocus 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.cpd110 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_3_0.com90 {
        array set save {-command 1 -entrybg 1 -highlightcolor 1 -insertbackground 1 -modifycmd 1 -postcommand 1 -selectbackground 1 -selectforeground 1 -takefocus 1 -textvariable 1 -values 1 -width 1}
    }
    namespace eval ::widgets::$base.fra92 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    set site_3_0 $base.fra92
    namespace eval ::widgets::$site_3_0.fra94 {
        array set save {-height 1 -width 1}
    }
    namespace eval ::widgets::$base.fra93 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    set site_3_0 $base.fra93
    namespace eval ::widgets::$site_3_0.but99 {
        array set save {-_tooltip 1 -command 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_3_0.lab100 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_3_0.spi101 {
        array set save {-command 1 -entrybg 1 -entryfg 1 -highlightcolor 1 -insertbackground 1 -modifycmd 1 -range 1 -selectbackground 1 -selectforeground 1 -takefocus 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.cpd102 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_3_0.cpd103 {
        array set save {-command 1 -entrybg 1 -entryfg 1 -highlightcolor 1 -insertbackground 1 -modifycmd 1 -range 1 -selectbackground 1 -selectforeground 1 -takefocus 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.cpd104 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_3_0.cpd105 {
        array set save {-command 1 -entrybg 1 -entryfg 1 -highlightcolor 1 -insertbackground 1 -modifycmd 1 -range 1 -selectbackground 1 -selectforeground 1 -takefocus 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.cpd106 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_3_0.cpd107 {
        array set save {-command 1 -entrybg 1 -entryfg 1 -highlightcolor 1 -insertbackground 1 -modifycmd 1 -range 1 -selectbackground 1 -selectforeground 1 -takefocus 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.but96 {
        array set save {-_tooltip 1 -command 1 -height 1 -image 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.but97 {
        array set save {-_tooltip 1 -command 1 -image 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.but98 {
        array set save {-_tooltip 1 -command 1 -image 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.cpd91 {
        array set save {-command 1 -editable 1 -entrybg 1 -entryfg 1 -highlightcolor 1 -insertbackground 1 -modifycmd 1 -range 1 -selectbackground 1 -selectforeground 1 -takefocus 1 -textvariable 1 -values 1 -width 1}
    }
    namespace eval ::widgets::$base.fra95 {
        array set save {-height 1 -width 1}
    }
    set site_3_0 $base.fra95
    namespace eval ::widgets::$site_3_0.scr118 {
        array set save {-command 1 -orient 1}
    }
    namespace eval ::widgets::$site_3_0.scr119 {
        array set save {-command 1}
    }
    namespace eval ::widgets::$site_3_0.tex120 {
        array set save {-background 1 -foreground 1 -height 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1 -wrap 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::$base.fra113 {
        array set save {-borderwidth 1 -height 1 -width 1}
    }
    set site_3_0 $base.fra113
    namespace eval ::widgets::$site_3_0.fra90 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    set site_4_0 $site_3_0.fra90
    namespace eval ::widgets::$site_4_0.cpd92 {
        array set save {-font 1 -text 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_3_0.cpd94 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    set site_4_0 $site_3_0.cpd94
    namespace eval ::widgets::$site_4_0.cpd95 {
        array set save {-_tooltip 1 -borderwidth 1 -font 1 -justify 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.cpd100 {
        array set save {-_tooltip 1 -borderwidth 1 -font 1 -justify 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.cpd102 {
        array set save {-_tooltip 1 -borderwidth 1 -font 1 -justify 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.cpd104 {
        array set save {-_tooltip 1 -borderwidth 1 -font 1 -justify 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.fra91 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    set site_4_0 $site_3_0.fra91
    namespace eval ::widgets::$site_4_0.cpd93 {
        array set save {-font 1 -foreground 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist {_TopLevel _vTclBalloon}
    }
    namespace eval ::vTcl::modules::main {
        set procs {
            init
            main
        }
        set compounds {
        }
        set projectType single
    }
}
}

#################################
# USER DEFINED PROCEDURES
#
#############################################################################
## Procedure:  main

proc ::main {argc argv} {}

#############################################################################
## Initialization Procedure:  init

proc ::init {argc argv} {
if {[info command q] == {}} then { proc q { args } { } }
option add *Dialog.msg.font {Helvetica 12}
}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    wm focusmodel $top passive
    wm geometry $top 1x1+0+0; update
    wm maxsize $top 1265 994
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm withdraw $top
    wm title $top "vtcl.tcl"
    bindtags $top "$top Vtcl.tcl all"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top90 {base} {
    if {$base == ""} {
        set base .top90
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel \
        -highlightcolor black 
    wm focusmodel $top passive
    wm geometry $top 535x616; update
    wm maxsize $top 1265 994
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm deiconify $top
    wm title $top "scgui"
    vTcl:DefineAlias "$top" "Toplevel1" vTcl:Toplevel:WidgetProc "" 1
    bindtags $top "$top Toplevel all _TopLevel"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    frame $top.fra91 \
        -borderwidth 2 -relief raised -height 75 -width 125 
    vTcl:DefineAlias "$top.fra91" "Frame1" vTcl:WidgetProc "Toplevel1" 1
    set site_3_0 $top.fra91
    button $site_3_0.but91 \
        -command {q scgui::open_cb} \
        -image [vTcl:image:get_image [file join / home ag cvs q q-synth images open.gif]] \
        -text Open 
    vTcl:DefineAlias "$site_3_0.but91" "FilenameButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.but91 "$site_3_0.but91 Button $top all _vTclBalloon"
    bind $site_3_0.but91 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Open}
    }
    entry $site_3_0.ent90 \
        -background white -insertbackground black \
        -textvariable filename -width 10 
    vTcl:DefineAlias "$site_3_0.ent90" "FilenameEntry" vTcl:WidgetProc "Toplevel1" 1
    button $site_3_0.cpd90 \
        -command {q scgui::edit_cb} \
        -image [vTcl:image:get_image [file join / home ag cvs q q-synth images edit.gif]] \
        -text Edit 
    vTcl:DefineAlias "$site_3_0.cpd90" "Button7" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.cpd90 "$site_3_0.cpd90 Button $top all _vTclBalloon"
    bind $site_3_0.cpd90 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Edit}
    }
    button $site_3_0.but92 \
        -command {q scgui::compile_cb} \
        -image [vTcl:image:get_image [file join / home ag cvs q q-synth images make.gif]] \
        -text Compile 
    vTcl:DefineAlias "$site_3_0.but92" "Button6" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.but92 "$site_3_0.but92 Button $top all _vTclBalloon"
    bind $site_3_0.but92 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Compile}
    }
    ComboBox $site_3_0.com92 \
        -command {q scgui::synth_cb} \
        -entrybg white -highlightcolor black -insertbackground black \
        -modifycmd {q scgui::synth_cb} -postcommand {q scgui::synth_post_cb} \
        -selectbackground #c1c2c1 -selectforeground black -takefocus 1 \
        -textvariable synth -width 12 
    vTcl:DefineAlias "$site_3_0.com92" "SynthComboBox" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.com92 "$site_3_0.com92 BwComboBox $top all"
    label $site_3_0.lab93 \
        -text Voices 
    vTcl:DefineAlias "$site_3_0.lab93" "Label1" vTcl:WidgetProc "Toplevel1" 1
    SpinBox $site_3_0.spi95 \
        -command {q scgui::voices_cb} \
        -entrybg white -entryfg black -highlightcolor black \
        -insertbackground black -modifycmd {q scgui::voices_cb} \
        -range {0 100 1} -selectbackground #c1c2c1 -selectforeground black \
        -takefocus 1 -text 0 -textvariable voices -width 3 
    vTcl:DefineAlias "$site_3_0.spi95" "VoicesSpinBox" vTcl:WidgetProc "Toplevel1" 1
    label $site_3_0.cpd110 \
        -text Chan 
    vTcl:DefineAlias "$site_3_0.cpd110" "Label6" vTcl:WidgetProc "Toplevel1" 1
    ComboBox $site_3_0.com90 \
        -command {q scgui::chan_cb} \
        -entrybg white -highlightcolor black -insertbackground black \
        -modifycmd {q scgui::chan_cb} -postcommand {q scgui::chan_post_cb} \
        -selectbackground #c1c2c1 -selectforeground black -takefocus 1 \
        -textvariable chan \
        -values {All 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16} -width 4 
    vTcl:DefineAlias "$site_3_0.com90" "ChanComboBox" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.com90 "$site_3_0.com90 BwComboBox $top all"
    pack $site_3_0.but91 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.ent90 \
        -in $site_3_0 -anchor center -expand 1 -fill x -side left 
    pack $site_3_0.cpd90 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.but92 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.com92 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.lab93 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.spi95 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.cpd110 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.com90 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    frame $top.fra92 \
        -borderwidth 2 -relief sunken -height 189 -width 125 
    vTcl:DefineAlias "$top.fra92" "Frame2" vTcl:WidgetProc "Toplevel1" 1
    bind $top.fra92 <Expose> {
        q scgui::expose_cb %c
    }
    set site_3_0 $top.fra92
    frame $site_3_0.fra94 \
        -height 255 -width 500 
    vTcl:DefineAlias "$site_3_0.fra94" "Wave" vTcl:WidgetProc "Toplevel1" 1
    pack $site_3_0.fra94 \
        -in $site_3_0 -anchor center -expand 0 -fill both -side top 
    frame $top.fra93 \
        -borderwidth 2 -relief raised -height 75 -width 125 
    vTcl:DefineAlias "$top.fra93" "Frame3" vTcl:WidgetProc "Toplevel1" 1
    set site_3_0 $top.fra93
    button $site_3_0.but99 \
        -command {q scgui::boot_cb} \
        -textvariable server 
    vTcl:DefineAlias "$site_3_0.but99" "BootButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.but99 "$site_3_0.but99 Button $top all _vTclBalloon"
    bind $site_3_0.but99 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Boot/Quit}
    }
    label $site_3_0.lab100 \
        -text Vol 
    vTcl:DefineAlias "$site_3_0.lab100" "Label2" vTcl:WidgetProc "Toplevel1" 1
    SpinBox $site_3_0.spi101 \
        -command {q scgui::vol_cb} -entrybg white \
        -entryfg black -highlightcolor black -insertbackground black \
        -modifycmd {q scgui::vol_cb} -range {0 10 0.1} \
        -selectbackground #c1c2c1 -selectforeground black -takefocus 1 \
        -text 0 -textvariable vol -width 4 
    vTcl:DefineAlias "$site_3_0.spi101" "VolSpinBox" vTcl:WidgetProc "Toplevel1" 1
    label $site_3_0.cpd102 \
        -text Pan 
    vTcl:DefineAlias "$site_3_0.cpd102" "Label3" vTcl:WidgetProc "Toplevel1" 1
    SpinBox $site_3_0.cpd103 \
        -command {q scgui::pan_cb} -entrybg white \
        -entryfg black -highlightcolor black -insertbackground black \
        -modifycmd {q scgui::pan_cb} -range {-1 1 0.1} \
        -selectbackground #c1c2c1 -selectforeground black -takefocus 1 \
        -text 0 -textvariable pan -width 4 
    vTcl:DefineAlias "$site_3_0.cpd103" "PanSpinBox" vTcl:WidgetProc "Toplevel1" 1
    label $site_3_0.cpd104 \
        -text Rev 
    vTcl:DefineAlias "$site_3_0.cpd104" "Label4" vTcl:WidgetProc "Toplevel1" 1
    SpinBox $site_3_0.cpd105 \
        -command {q scgui::rev_cb} -entrybg white \
        -entryfg black -highlightcolor black -insertbackground black \
        -modifycmd {q scgui::rev_cb} -range {0 1 0.01} \
        -selectbackground #c1c2c1 -selectforeground black -takefocus 1 \
        -text 0 -textvariable rev -width 4 
    vTcl:DefineAlias "$site_3_0.cpd105" "RevSpinBox" vTcl:WidgetProc "Toplevel1" 1
    label $site_3_0.cpd106 \
        -text Rec 
    vTcl:DefineAlias "$site_3_0.cpd106" "Label5" vTcl:WidgetProc "Toplevel1" 1
    SpinBox $site_3_0.cpd107 \
        -command {q scgui::rec_cb} -entrybg white \
        -entryfg black -highlightcolor black -insertbackground black \
        -modifycmd {q scgui::rec_cb} -range {0 10 0.1} \
        -selectbackground #c1c2c1 -selectforeground black -takefocus 1 \
        -text 0 -textvariable rec -width 4 
    vTcl:DefineAlias "$site_3_0.cpd107" "ChorSpinBox" vTcl:WidgetProc "Toplevel1" 1
    button $site_3_0.but96 \
        -command {q scgui::start_cb} -height 22 \
        -image [vTcl:image:get_image [file join / home ag cvs q q-synth images play.gif]] \
        -text Play 
    vTcl:DefineAlias "$site_3_0.but96" "PlayButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.but96 "$site_3_0.but96 Button $top all _vTclBalloon"
    bind $site_3_0.but96 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Play}
    }
    button $site_3_0.but97 \
        -command {q scgui::stop_cb} \
        -image [vTcl:image:get_image [file join / home ag cvs q q-synth images stop.gif]] \
        -text Stop 
    vTcl:DefineAlias "$site_3_0.but97" "StopButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.but97 "$site_3_0.but97 Button $top all _vTclBalloon"
    bind $site_3_0.but97 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Stop}
    }
    button $site_3_0.but98 \
        -command {q scgui::record_cb} \
        -image [vTcl:image:get_image [file join / home ag cvs q q-synth images record.gif]] \
        -text Record 
    vTcl:DefineAlias "$site_3_0.but98" "RecordButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.but98 "$site_3_0.but98 Button $top all _vTclBalloon"
    bind $site_3_0.but98 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Record}
    }
    SpinBox $site_3_0.cpd91 \
        -command {q scgui::bufsz_cb} -editable 0 \
        -entrybg white -entryfg black -highlightcolor black \
        -insertbackground black -modifycmd {q scgui::bufsz_cb} \
        -range {0 8192 1} -selectbackground #c1c2c1 -selectforeground black \
        -takefocus 0 -textvariable bufsz -values {512 1024 2048 4096 8192} \
        -width 5 
    vTcl:DefineAlias "$site_3_0.cpd91" "ChorSpinBox1" vTcl:WidgetProc "Toplevel1" 1
    pack $site_3_0.but99 \
        -in $site_3_0 -anchor center -expand 1 -fill x -padx 4 -side left 
    pack $site_3_0.lab100 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.spi101 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.cpd102 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.cpd103 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.cpd104 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.cpd105 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.cpd106 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.cpd107 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.but96 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.but97 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.but98 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.cpd91 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    frame $top.fra95 \
        -height 55 -width 125 
    vTcl:DefineAlias "$top.fra95" "Frame5" vTcl:WidgetProc "Toplevel1" 1
    set site_3_0 $top.fra95
    scrollbar $site_3_0.scr118 \
        -command "$site_3_0.tex120 xview" -orient horizontal 
    vTcl:DefineAlias "$site_3_0.scr118" "HScrollbar" vTcl:WidgetProc "Toplevel1" 1
    scrollbar $site_3_0.scr119 \
        -command "$site_3_0.tex120 yview" 
    vTcl:DefineAlias "$site_3_0.scr119" "VScrollbar" vTcl:WidgetProc "Toplevel1" 1
    text $site_3_0.tex120 \
        -background white -foreground black -height 15 -highlightcolor black \
        -insertbackground black -selectbackground #c1c2c1 \
        -selectforeground black -wrap none \
        -xscrollcommand "$site_3_0.scr118 set" \
        -yscrollcommand "$site_3_0.scr119 set" 
    vTcl:DefineAlias "$site_3_0.tex120" "Output" vTcl:WidgetProc "Toplevel1" 1
    grid $site_3_0.scr118 \
        -in $site_3_0 -column 0 -row 1 -columnspan 1 -rowspan 1 -sticky ew 
    grid $site_3_0.scr119 \
        -in $site_3_0 -column 1 -row 0 -columnspan 1 -rowspan 1 -sticky ns 
    grid $site_3_0.tex120 \
        -in $site_3_0 -column 0 -row 0 -columnspan 1 -rowspan 1 -sticky nesw 
    frame $top.fra113 \
        -borderwidth 2 -height 75 -width 125 
    vTcl:DefineAlias "$top.fra113" "Frame4" vTcl:WidgetProc "Toplevel1" 1
    set site_3_0 $top.fra113
    frame $site_3_0.fra90 \
        -borderwidth 2 -relief sunken -height 75 -width 125 
    vTcl:DefineAlias "$site_3_0.fra90" "Frame6" vTcl:WidgetProc "Toplevel1" 1
    set site_4_0 $site_3_0.fra90
    label $site_4_0.cpd92 \
        -font {Helvetica -12} -text {} \
        -textvariable status 
    vTcl:DefineAlias "$site_4_0.cpd92" "StatusLabel" vTcl:WidgetProc "Toplevel1" 1
    pack $site_4_0.cpd92 \
        -in $site_4_0 -anchor center -expand 0 -fill x -side left 
    frame $site_3_0.cpd94 \
        -borderwidth 2 -relief sunken -height 75 -width 125 
    vTcl:DefineAlias "$site_3_0.cpd94" "Frame8" vTcl:WidgetProc "Toplevel1" 1
    set site_4_0 $site_3_0.cpd94
    label $site_4_0.cpd95 \
        -borderwidth 1 -font {Helvetica -12} \
        -justify left -relief sunken -textvariable defs -width 3 
    vTcl:DefineAlias "$site_4_0.cpd95" "RecLabel2" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.cpd95 "$site_4_0.cpd95 Label $top all _vTclBalloon"
    bind $site_4_0.cpd95 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Defs}
    }
    label $site_4_0.cpd100 \
        -borderwidth 1 -font {Helvetica -12} \
        -justify left -relief sunken -textvariable groups -width 3 
    vTcl:DefineAlias "$site_4_0.cpd100" "RecLabel4" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.cpd100 "$site_4_0.cpd100 Label $top all _vTclBalloon"
    bind $site_4_0.cpd100 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Groups}
    }
    label $site_4_0.cpd102 \
        -borderwidth 1 -font {Helvetica -12} \
        -justify left -relief sunken -textvariable synths -width 3 
    vTcl:DefineAlias "$site_4_0.cpd102" "RecLabel6" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.cpd102 "$site_4_0.cpd102 Label $top all _vTclBalloon"
    bind $site_4_0.cpd102 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Synths}
    }
    label $site_4_0.cpd104 \
        -borderwidth 1 -font {Helvetica -12} \
        -justify left -relief sunken -textvariable ugens -width 4 
    vTcl:DefineAlias "$site_4_0.cpd104" "RecLabel8" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.cpd104 "$site_4_0.cpd104 Label $top all _vTclBalloon"
    bind $site_4_0.cpd104 <<SetBalloon>> {
        set ::vTcl::balloon::%W {UGens}
    }
    pack $site_4_0.cpd95 \
        -in $site_4_0 -anchor w -expand 0 -fill none -side left 
    pack $site_4_0.cpd100 \
        -in $site_4_0 -anchor w -expand 0 -fill none -side left 
    pack $site_4_0.cpd102 \
        -in $site_4_0 -anchor w -expand 0 -fill none -side left 
    pack $site_4_0.cpd104 \
        -in $site_4_0 -anchor w -expand 0 -fill none -side left 
    frame $site_3_0.fra91 \
        -borderwidth 2 -relief sunken -height 75 -width 125 
    vTcl:DefineAlias "$site_3_0.fra91" "Frame7" vTcl:WidgetProc "Toplevel1" 1
    set site_4_0 $site_3_0.fra91
    label $site_4_0.cpd93 \
        -font {Helvetica -12} -foreground #ff0000 \
        -textvariable recstat -width 5 
    vTcl:DefineAlias "$site_4_0.cpd93" "RecLabel" vTcl:WidgetProc "Toplevel1" 1
    pack $site_4_0.cpd93 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.fra90 \
        -in $site_3_0 -anchor center -expand 1 -fill x -side left 
    pack $site_3_0.cpd94 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.fra91 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    ###################
    # SETTING GEOMETRY
    ###################
    pack $top.fra91 \
        -in $top -anchor center -expand 0 -fill x -side top 
    pack $top.fra92 \
        -in $top -anchor center -expand 0 -fill both -side top 
    pack $top.fra93 \
        -in $top -anchor center -expand 0 -fill x -side top 
    pack $top.fra95 \
        -in $top -anchor center -expand 1 -fill both -side top 
    grid columnconf $top.fra95 0 -weight 1
    grid rowconf $top.fra95 0 -weight 1
    pack $top.fra113 \
        -in $top -anchor center -expand 0 -fill x -side top 

    vTcl:FireEvent $base <<Ready>>
}

#############################################################################
## Binding tag:  _TopLevel

bind "_TopLevel" <<Create>> {
    if {![info exists _topcount]} {set _topcount 0}; incr _topcount
}
bind "_TopLevel" <<DeleteWindow>> {
    if {[set ::%W::_modal]} {
                vTcl:Toplevel:WidgetProc %W endmodal
            } else {
                destroy %W; if {$_topcount == 0} {exit}
            }
}
bind "_TopLevel" <Destroy> {
    if {[winfo toplevel %W] == "%W"} {incr _topcount -1}
}
#############################################################################
## Binding tag:  _vTclBalloon


if {![info exists vTcl(sourcing)]} {
bind "_vTclBalloon" <<KillBalloon>> {
    namespace eval ::vTcl::balloon {
        after cancel $id
        if {[winfo exists .vTcl.balloon]} {
            destroy .vTcl.balloon
        }
        set set 0
    }
}
bind "_vTclBalloon" <<vTclBalloon>> {
    if {$::vTcl::balloon::first != 1} {break}

    namespace eval ::vTcl::balloon {
        set first 2
        if {![winfo exists .vTcl]} {
            toplevel .vTcl; wm withdraw .vTcl
        }
        if {![winfo exists .vTcl.balloon]} {
            toplevel .vTcl.balloon -bg black
        }
        wm overrideredirect .vTcl.balloon 1
        label .vTcl.balloon.l  -text ${%W} -relief flat  -bg #ffffaa -fg black -padx 2 -pady 0 -anchor w
        pack .vTcl.balloon.l -side left -padx 1 -pady 1
        wm geometry  .vTcl.balloon  +[expr {[winfo rootx %W]+[winfo width %W]/2}]+[expr {[winfo rooty %W]+[winfo height %W]+4}]
        set set 1
    }
}
bind "_vTclBalloon" <Button> {
    namespace eval ::vTcl::balloon {
        set first 0
    }
    vTcl:FireEvent %W <<KillBalloon>>
}
bind "_vTclBalloon" <Enter> {
    namespace eval ::vTcl::balloon {
        ## self defining balloon?
        if {![info exists %W]} {
            vTcl:FireEvent %W <<SetBalloon>>
        }
        set set 0
        set first 1
        set id [after 500 {vTcl:FireEvent %W <<vTclBalloon>>}]
    }
}
bind "_vTclBalloon" <Leave> {
    namespace eval ::vTcl::balloon {
        set first 0
    }
    vTcl:FireEvent %W <<KillBalloon>>
}
bind "_vTclBalloon" <Motion> {
    namespace eval ::vTcl::balloon {
        if {!$set} {
            after cancel $id
            set id [after 500 {vTcl:FireEvent %W <<vTclBalloon>>}]
        }
    }
}
}

Window show .
Window show .top90

main $argc $argv
